==> CGAL-5.6.1-doc_html.tar.xz: doc_html/BGL/examples.js <==
var examples =
[
    [ "BGL_arrangement_2/arr_print.h", "BGL_arrangement_2_2arr_print_8h-example.html", null ],
    [ "BGL_arrangement_2/arr_rational_nt.h", "BGL_arrangement_2_2arr_rational_nt_8h-example.html", null ],
    [ "BGL_arrangement_2/arrangement_dual.cpp", "BGL_arrangement_2_2arrangement_dual_8cpp-example.html", null ],
    [ "BGL_arrangement_2/primal.cpp", "BGL_arrangement_2_2primal_8cpp-example.html", null ],
    [ "BGL_graphcut/alpha_expansion_example.cpp", "BGL_graphcut_2alpha_expansion_example_8cpp-example.html", null ],
    [ "BGL_graphcut/face_selection_borders_regularization_example.cpp", "BGL_graphcut_2face_selection_borders_regularization_example_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/copy_polyhedron.cpp", "BGL_polyhedron_3_2copy_polyhedron_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/distance.cpp", "BGL_polyhedron_3_2distance_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/incident_vertices.cpp", "BGL_polyhedron_3_2incident_vertices_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/kruskal.cpp", "BGL_polyhedron_3_2kruskal_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/kruskal_with_stored_id.cpp", "BGL_polyhedron_3_2kruskal_with_stored_id_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/normals.cpp", "BGL_polyhedron_3_2normals_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/polyhedron_partition.cpp", "BGL_polyhedron_3_2polyhedron_partition_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/range.cpp", "BGL_polyhedron_3_2range_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/transform_iterator.cpp", "BGL_polyhedron_3_2transform_iterator_8cpp-example.html", null ],
    [ "BGL_surface_mesh/connected_components.cpp", "BGL_surface_mesh_2connected_components_8cpp-example.html", null ],
    [ "BGL_surface_mesh/gwdwg.cpp", "BGL_surface_mesh_2gwdwg_8cpp-example.html", null ],
    [ "BGL_surface_mesh/prim.cpp", "BGL_surface_mesh_2prim_8cpp-example.html", null ],
    [ "BGL_surface_mesh/seam_mesh.cpp", "BGL_surface_mesh_2seam_mesh_8cpp-example.html", null ],
    [ "BGL_surface_mesh/surface_mesh_dual.cpp", "BGL_surface_mesh_2surface_mesh_dual_8cpp-example.html", null ],
    [ "BGL_surface_mesh/surface_mesh_partition.cpp", "BGL_surface_mesh_2surface_mesh_partition_8cpp-example.html", null ],
    [ "BGL_surface_mesh/write_inp.cpp", "BGL_surface_mesh_2write_inp_8cpp-example.html", null ],
    [ "BGL_triangulation_2/dijkstra.cpp", "BGL_triangulation_2_2dijkstra_8cpp-example.html", null ],
    [ "BGL_triangulation_2/dijkstra_with_internal_properties.cpp", "BGL_triangulation_2_2dijkstra_with_internal_properties_8cpp-example.html", null ],
    [ "BGL_triangulation_2/emst.cpp", "BGL_triangulation_2_2emst_8cpp-example.html", null ],
    [ "BGL_triangulation_2/emst_cdt_plus_hierarchy.cpp", "BGL_triangulation_2_2emst_cdt_plus_hierarchy_8cpp-example.html", null ],
    [ "BGL_triangulation_2/emst_regular.cpp", "BGL_triangulation_2_2emst_regular_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/face_filtered_graph_example.cpp", "Polygon_mesh_processing_2face_filtered_graph_example_8cpp-example.html", null ],
    [ "Polyhedron/poly_derivation.cpp", "Polyhedron_2poly_derivation_8cpp-example.html", null ],
    [ "Property_map/dynamic_properties.cpp", "Property_map_2dynamic_properties_8cpp-example.html", null ],
    [ "Surface_mesh/sm_derivation.cpp", "Surface_mesh_2sm_derivation_8cpp-example.html", null ],
    [ "Surface_mesh_segmentation/extract_segmentation_into_mesh_example.cpp", "Surface_mesh_segmentation_2extract_segmentation_into_mesh_example_8cpp-example.html", null ],
    [ "Surface_mesh_skeletonization/simple_mcfskel_example.cpp", "Surface_mesh_skeletonization_2simple_mcfskel_example_8cpp-example.html", null ]
];

==> CGAL-6.0.1-doc_html.tar.xz: doc_html/BGL/examples.js <==
var examples =
[
    [ "BGL_arrangement_2/arr_print.h", "BGL_arrangement_2_2arr_print_8h-example.html", null ],
    [ "BGL_arrangement_2/arr_rational_nt.h", "BGL_arrangement_2_2arr_rational_nt_8h-example.html", null ],
    [ "BGL_arrangement_2/arrangement_dual.cpp", "BGL_arrangement_2_2arrangement_dual_8cpp-example.html", null ],
    [ "BGL_arrangement_2/primal.cpp", "BGL_arrangement_2_2primal_8cpp-example.html", null ],
    [ "BGL_graphcut/alpha_expansion_example.cpp", "BGL_graphcut_2alpha_expansion_example_8cpp-example.html", null ],
    [ "BGL_graphcut/face_selection_borders_regularization_example.cpp", "BGL_graphcut_2face_selection_borders_regularization_example_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/copy_polyhedron.cpp", "BGL_polyhedron_3_2copy_polyhedron_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/distance.cpp", "BGL_polyhedron_3_2distance_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/incident_vertices.cpp", "BGL_polyhedron_3_2incident_vertices_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/kruskal.cpp", "BGL_polyhedron_3_2kruskal_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/kruskal_with_stored_id.cpp", "BGL_polyhedron_3_2kruskal_with_stored_id_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/normals.cpp", "BGL_polyhedron_3_2normals_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/polyhedron_partition.cpp", "BGL_polyhedron_3_2polyhedron_partition_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/range.cpp", "BGL_polyhedron_3_2range_8cpp-example.html", null ],
    [ "BGL_polyhedron_3/transform_iterator.cpp", "BGL_polyhedron_3_2transform_iterator_8cpp-example.html", null ],
    [ "BGL_triangulation_2/dijkstra.cpp", "BGL_triangulation_2_2dijkstra_8cpp-example.html", null ],
    [ "BGL_triangulation_2/dijkstra_with_internal_properties.cpp", "BGL_triangulation_2_2dijkstra_with_internal_properties_8cpp-example.html", null ],
    [ "BGL_triangulation_2/emst.cpp", "BGL_triangulation_2_2emst_8cpp-example.html", null ],
    [ "BGL_triangulation_2/emst_regular.cpp", "BGL_triangulation_2_2emst_regular_8cpp-example.html", null ],
    [ "BGL_triangulation_2/emst_cdt_plus_hierarchy.cpp", "BGL_triangulation_2_2emst_cdt_plus_hierarchy_8cpp-example.html", null ],
    [ "BGL_surface_mesh/prim.cpp", "BGL_surface_mesh_2prim_8cpp-example.html", null ],
    [ "BGL_surface_mesh/gwdwg.cpp", "BGL_surface_mesh_2gwdwg_8cpp-example.html", null ],
    [ "BGL_surface_mesh/seam_mesh.cpp", "BGL_surface_mesh_2seam_mesh_8cpp-example.html", null ],
    [ "BGL_surface_mesh/write_inp.cpp", "BGL_surface_mesh_2write_inp_8cpp-example.html", null ],
    [ "BGL_surface_mesh/surface_mesh_dual.cpp", "BGL_surface_mesh_2surface_mesh_dual_8cpp-example.html", null ],
    [ "BGL_surface_mesh/connected_components.cpp", "BGL_surface_mesh_2connected_components_8cpp-example.html", null ],
    [ "BGL_surface_mesh/surface_mesh_partition.cpp", "BGL_surface_mesh_2surface_mesh_partition_8cpp-example.html", null ],
    [ "Surface_mesh_skeletonization/simple_mcfskel_example.cpp", "Surface_mesh_skeletonization_2simple_mcfskel_example_8cpp-example.html", null ],
    [ "Surface_mesh_segmentation/extract_segmentation_into_mesh_example.cpp", "Surface_mesh_segmentation_2extract_segmentation_into_mesh_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/face_filtered_graph_example.cpp", "Polygon_mesh_processing_2face_filtered_graph_example_8cpp-example.html", null ],
    [ "Property_map/dynamic_properties.cpp", "Property_map_2dynamic_properties_8cpp-example.html", null ],
    [ "Surface_mesh/sm_derivation.cpp", "Surface_mesh_2sm_derivation_8cpp-example.html", null ],
    [ "Polyhedron/poly_derivation.cpp", "Polyhedron_2poly_derivation_8cpp-example.html", null ]
];
